@@ -6,7 +6,7 @@
   You may redistribute it and/or modify it under the same
   license terms as Ruby.
 
-  $Id: erb.rb,v 1.2 2005/08/20 17:05:34 mutoh Exp $
+  $Id: erb.rb,v 1.4 2006/02/22 16:42:41 mutoh Exp $
 =end
 
 require 'erb'
@@ -14,14 +14,30 @@ require 'gettext/parser/ruby.rb'
 
 module GetText
   module ErbParser
+    @config = {
+      :extnames => ['.rhtml']
+    }
+
     module_function
-    def parse(file, targets = [])
+    # Sets some preferences to parse ERB files.
+    # * config: a Hash of the config. It can takes some values below:
+    #   * :extnames: An Array of target files extension. Default is [".rhtml"].
+    def init(config)
+      config.each{|k, v|
+	@config[k] = v
+      }
+    end
+
+    def parse(file, targets = []) # :nodoc:
       erb = ERB.new(IO.readlines(file).join).src.split(/$/)
       RubyParser.parse_lines(file, erb, targets)
     end
 
-    def target?(file)
-      File.extname(file) == '.rhtml'
+    def target?(file) # :nodoc:
+      @config[:extnames].each do |v|
+	return true if File.extname(file) == v
+      end
+      false
     end
   end
 end
